import { A as ApiCallOptions } from './invoke-fetch-types-Cq7bjkqn.js';
import './auth-types-DqfMuSRX.js';

/**
 * An error object
 */
type APIError = {
    /** Qlik error code (not HTTP response status code) */
    code: string;
    /** Description of the error */
    detail?: string;
    /** Additional details about the error. These may vary by error. */
    meta?: {
        /** The argument */
        argument?: string;
        /** Extra details for what may have caused the error */
        details?: string;
        /** The unique id of the error instance */
        errorId?: string;
        /** The issue code */
        issue?: string;
        /** The resource type that the error occurred on */
        resource?: string;
        /** The resource id that the error occurred on */
        resourceId?: string;
    };
    /** Short summary of error */
    title: string;
};
/**
 * An AutoML alias
 */
type Alias = {
    /** Timestamp when this was created */
    createdAt: CreatedAt;
    /** ID of the owner/user that created this entity */
    createdBy: string;
    /** ID of a model deployment */
    deploymentId: DeploymentId;
    /** ID of this entity */
    id: EntityId;
    /** The mode of an alias. Default mode means the model assigned to that alias will be used if alias is not specified */
    mode: AliasMode;
    models: ModelsInfo;
    /** Name of this entity */
    name: EntityName;
    /** Timestamp when this was updated */
    updatedAt: UpdatedAt;
};
type AliasFindResponse = {
    data: {
        /** An AutoML alias */
        attributes: Alias;
        /** ID of this entity */
        id: EntityId;
        type: "alias";
    }[];
    /** Resource links included in paginated responses */
    links: ResponseLinks;
    /** Meta for FIND operations */
    meta?: FindResponseMeta;
};
type AliasGetResponse = {
    data: {
        /** An AutoML alias */
        attributes: Alias;
        /** ID of this entity */
        id: EntityId;
        type: "alias";
    };
};
/**
 * ID of an alias
 */
type AliasId = string;
/**
 * Input for creating a new alias
 */
type AliasInput = {
    data: {
        attributes: {
            models: ModelsInfo;
            /** Name of this entity */
            name: EntityName;
        };
        type: "alias";
    };
};
/**
 * The mode of an alias. Default mode means the model assigned to that alias will be used if alias is not specified
 */
type AliasMode = "default" | "undefined";
type AliasPatch = AliasPatchItem[];
/**
 * Alias values that can be patched.
 * @example
 * {
 *   op: "replace",
 *   path: "/name"
 * }
 */
type AliasPatchItem = {
    /** All patch requests use the replace operation */
    op: "replace";
    /** Path for the property you want to update */
    path: "/name" | "/models";
    /** Use for fields that can be `any` type (string, number, etc.) */
    value: AnyType;
};
type AliasPostResponse = {
    data: {
        /** An AutoML alias */
        attributes: Alias;
        /** ID of this entity */
        id: EntityId;
        type: "alias";
    };
};
/**
 * Use for fields that can be `any` type (string, number, etc.)
 */
type AnyType = unknown;
/**
 * A batch prediction job configuration
 */
type BatchPrediction = {
    /** ID of an alias */
    aliasId?: AliasId;
    /** Timestamp when this was created */
    createdAt?: CreatedAt;
    /** ID of the owner/user that ran this prediction batch */
    createdBy?: string;
    /** The Qlik catalog dataset ID */
    dataSetId?: DataSetId;
    /** ID of the dataset with the prediction results */
    datasetId?: string;
    /** ID of a model deployment */
    deploymentId?: DeploymentId;
    /** JSON string of error object */
    errorMessage?: ErrorMessage;
    /** JSON string with list of error objects */
    errors?: Errors;
    /** ID of this entity */
    id?: EntityId;
    /** A optional column name upon which to create an index. Must be unique for
     * every row. If not included, Qlik will create a unique index column. */
    indexColumn?: IndexColumn;
    /** Name of this entity */
    name?: EntityName;
    /** Where to output dataset */
    outputDataset?: string;
    /** ID of owner/user for this entity */
    ownerId?: OwnerId;
    /** Batch prediction job schedule */
    schedule?: BatchPredictionSchedule;
    /** Status of this batch prediction */
    status?: BatchPredictionStatus;
    /** Timestamp when this was updated */
    updatedAt?: UpdatedAt;
    /** Sets which files, file names, and spaces are used to write results of
     * batch predictions (output files) to the catalog. */
    writeback?: BatchPredictionWriteback;
};
/**
 * Response for batch prediction predict action that indicates job and status
 */
type BatchPredictionActionResponse = {
    data: {
        attributes: PredictionJobResponse;
        /** ID of this entity */
        id: EntityId;
        type: "job";
    };
};
type BatchPredictionFindResponse = {
    data: {
        /** A batch prediction job configuration */
        attributes: BatchPrediction;
        /** ID of this entity */
        id: EntityId;
        type: "batch-prediction";
    }[];
    /** Resource links included in paginated responses */
    links: ResponseLinks;
    /** Meta for FIND operations */
    meta?: FindResponseMeta;
};
type BatchPredictionGetResponse = {
    data: {
        /** A batch prediction job configuration */
        attributes: BatchPrediction;
        /** ID of this entity */
        id: EntityId;
        type: "batch-prediction";
    };
};
/**
 * Input values for creating a batch prediction configuration
 */
type BatchPredictionInput = {
    data?: {
        attributes?: {
            /** ID of an alias */
            aliasId?: AliasId;
            /** The Qlik catalog dataset ID */
            dataSetId?: DataSetId;
            /** ID of a model deployment */
            deploymentId?: DeploymentId;
            description?: string;
            /** A optional column name upon which to create an index. Must be unique for
             * every row. If not included, Qlik will create a unique index column. */
            indexColumn?: IndexColumn;
            /** Name of this entity */
            name?: EntityName;
            /** Configuration to schedule a batch prediction */
            schedule?: BatchPredictionScheduleInputAttributes;
            /** Sets which files, file names, and spaces are used to write results of
             * batch predictions (output files) to the catalog. */
            writeback?: BatchPredictionWriteback;
        };
        type?: "batch-prediction";
    };
};
type BatchPredictionPatch = {
    /** All patch requests use the replace operation */
    op: "replace";
    /** Path for the property you want to update */
    path: "/name" | "/description" | "/dataSetId" | "/indexColumn" | "/applyDatasetChangeOnly" | "/ownerId" | "/writeback/spaceId" | "/writeback/format" | "/writeback/dstName" | "/writeback/dstShapName" | "/writeback/dstCoordShapName" | "/writeback/dstNotPredictedName" | "/writeback/dstSourceName";
    /** Use for fields that can be `any` type (string, number, etc.) */
    value: AnyType;
}[];
type BatchPredictionPostResponse = {
    data: {
        /** A batch prediction job configuration */
        attributes: BatchPrediction;
        /** ID of this entity */
        id: EntityId;
        type: "batch-prediction";
    };
};
/**
 * Batch prediction job schedule
 */
type BatchPredictionSchedule = {
    /** If true, only run prediction if dataset has changed to avoid
     * duplicates. If set to false, re-runs predictions on unchanged
     * datasets. */
    applyDatasetChangeOnly?: boolean;
    /** The ID of the chronos job */
    chronosJobId?: string;
    /** When the job finished */
    endDateTime?: string;
    /** Number of times a scheduled prediction job has failed */
    failureAttempts?: number;
    /** When the last successful job happened */
    lastSuccessfulDateTime?: string;
    /** Recurrence rules. Maximum is DAILY but you can specify the
     * hour, minute, and second it runs each day.
     * One string per rule. */
    recurrence?: string[];
    /** When the job is scheduled to start */
    startDateTime?: string;
    /** The status of the schedule */
    status?: "pending" | "active" | "error" | "error_scheduler_unreachable" | "error_scheduler_callback_error" | "licence_advanced_features_required" | "failing_schedule_permission";
    /** Timezone used for the date-time fields */
    timezone?: string;
};
type BatchPredictionScheduleGetResponse = {
    data: {
        /** Batch prediction job schedule */
        attributes: BatchPredictionSchedule;
        /** ID of this entity */
        id: EntityId;
        type: "batch-prediction-schedule";
    };
};
/**
 * Input values for a batch prediction schedule
 */
type BatchPredictionScheduleInput = {
    data?: {
        /** Configuration to schedule a batch prediction */
        attributes?: BatchPredictionScheduleInputAttributes;
        type?: "batch-prediction-schedule";
    };
};
/**
 * Configuration to schedule a batch prediction
 */
type BatchPredictionScheduleInputAttributes = {
    /** If true, only run prediction if dataset has changed to avoid
     * duplicates. If set to false, re-runs predictions on unchanged
     * datasets. */
    applyDatasetChangeOnly?: boolean;
    /** When the job is scheduled to finish */
    endDateTime?: string;
    /** Recurrence rules. Maximum is DAILY but you can specify the
     * hour, minute, and second it runs each day.
     * One string per rule. */
    recurrence?: string[];
    /** When the job is scheduled to start */
    startDateTime: string;
    /** Timezone used for the date-time fields */
    timezone: string;
};
type BatchPredictionSchedulePatch = {
    /** All patch requests use the replace operation */
    op: "replace";
    /** Path for the property you want to update */
    path: "/startDateTime" | "/endDateTime" | "/timezone" | "/recurrence" | "/applyDatasetChangeOnly";
    /** Use for fields that can be `any` type (string, number, etc.) */
    value: AnyType;
}[];
type BatchPredictionSchedulePutResponse = {
    data: {
        /** Batch prediction job schedule */
        attributes: BatchPredictionSchedule;
        /** ID of this entity */
        id: EntityId;
        type: "batch-prediction-schedule";
    };
};
/**
 * Status of this batch prediction
 */
type BatchPredictionStatus = "modified" | "ready" | "error" | "cancelled" | "pending";
/**
 * Sets which files, file names, and spaces are used to write results of
 * batch predictions (output files) to the catalog.
 */
type BatchPredictionWriteback = {
    dstCoordShapName?: string;
    dstName: string;
    dstNotPredictedName?: string;
    dstShapName?: string;
    dstSourceName?: string;
    /** File format for write back files (this applies to all) */
    format: "qvd" | "parquet" | "csv";
    /** Space ID where you want to save batch prediction writebacks or
     * empty string ('') save them to your personal space. */
    spaceId: string;
};
type BinaryImbalanceSampling = {
    sampleClass?: string;
    sampleDirection?: "up" | "down";
    sampleRatio?: number;
};
/**
 * Indicates if you want to change the featureType for this
 * feature within the experiment version
 */
type ChangeType = "categorical" | "numeric" | "date" | "freetext";
type ColumnTransform = {
    changeType: string;
    name: string;
};
type ConfigurationKey = "DATE_INDEX" | "FUTURE_FEATURE" | "GROUP_ID" | "FORECAST_GAP_SIZE" | "FORECAST_WINDOW_SIZE";
/**
 * The ID of a correlated resource of corrType
 */
type CorrId = string;
/**
 * Types names of correlated resources (batch 'prediction' and
 * experiment_version)
 */
type CorrType = "batch-prediction" | "experiment-version";
/**
 * Timestamp when this was created
 */
type CreatedAt = string;
/**
 * ID of the owner/user that created this entity.
 */
type CreatedBy = string;
type DataSchemaConfiguration = {
    key: ConfigurationKey;
    value: string;
};
/**
 * The Qlik catalog dataset ID
 * @example
 * "672e55cfcadfb8a18281523e"
 */
type DataSetId = string;
/**
 * The data type of this feature in your dataset
 * @example
 * "STRING"
 */
type DataType = "DATE" | "TIME" | "DATETIME" | "TIMESTAMP" | "STRING" | "DOUBLE" | "DECIMAL" | "INTEGER" | "BOOLEAN" | "BINARY" | "CUSTOM" | "FLOAT" | "OBJECT";
/**
 * Whether this is a new or other dataset
 */
type DatasetOrigin = "new" | "changed" | "refreshed" | "same";
/**
 * A optional date column name to index
 */
type DateIndexes = string[];
/**
 * Timestamp when this is deleted
 */
type DeletedAt = string;
/**
 * IDs of all models deployed to the deployment
 */
type DeployedModelIds = string[];
/**
 * Input values for adding deployed models to a deployment
 */
type DeployedModelsInput = {
    data: {
        attributes: {
            /** IDs of all models deployed to the deployment */
            deployedModelIds: DeployedModelIds;
        };
        type: "deployed-models";
    };
};
/**
 * A deployed model against which you can run predictions
 */
type Deployment = {
    /** Timestamp when this was created */
    createdAt: CreatedAt;
    /** ID of the owner/user that created this entity. */
    createdBy: CreatedBy;
    /** IDs of all models deployed to the deployment */
    deployedModelIds?: DeployedModelIds;
    /** Whether this deployment is deprecated */
    deprecated: boolean;
    /** Description of this entity */
    description: EntityDescription;
    /** Whether to allow predictions */
    enablePredictions: boolean;
    /** JSON string of error object */
    errorMessage?: ErrorMessage;
    /** JSON string with list of error objects */
    errors?: Errors;
    /** ID of this entity */
    id: EntityId;
    /** ID of the model */
    modelId: ModelId;
    /** Name of this entity */
    name: EntityName;
    /** ID of owner/user for this entity */
    ownerId: OwnerId;
    /** Space ID for this entity (empty string for personal space) */
    spaceId: SpaceId;
    /** Timestamp when this was updated */
    updatedAt: UpdatedAt;
};
type DeploymentFindResponse = {
    data: {
        /** A deployed model against which you can run predictions */
        attributes: Deployment;
        /** ID of this entity */
        id: EntityId;
        type: "deployment";
    }[];
    /** Resource links included in paginated responses */
    links: ResponseLinks;
    /** Meta for FIND operations */
    meta?: FindResponseMeta;
};
type DeploymentGetResponse = {
    data: {
        /** A deployed model against which you can run predictions */
        attributes: Deployment;
        /** ID of this entity */
        id: EntityId;
        type: "deployment";
    };
};
/**
 * ID of a model deployment
 */
type DeploymentId = string;
/**
 * Input for creating a new deployment
 */
type DeploymentInput = {
    data?: {
        attributes?: {
            /** Whether this deployment is deprecated */
            deprecated?: boolean;
            /** Description of this entity */
            description?: EntityDescription;
            /** Whether to allow real-time predictions */
            enablePredictions?: boolean;
            /** ID of the model */
            modelId: ModelId;
            /** Name of this entity */
            name: EntityName;
            /** Space ID for this entity (empty string for personal space) */
            spaceId: SpaceId;
        };
        type?: "deployment";
    };
};
type DeploymentPatch = {
    /** All patch requests use the replace operation */
    op: "replace";
    /** Path for the property you want to update */
    path: "/name" | "/description" | "/spaceId";
    /** Use for fields that can be `any` type (string, number, etc.) */
    value: AnyType;
}[];
type DeploymentPostResponse = {
    data: {
        /** A deployed model against which you can run predictions */
        attributes: Deployment;
        /** ID of this entity */
        id: EntityId;
        type: "deployment";
    };
};
/**
 * Feature dropped during preprocessing
 */
type DroppedFeature = {
    /** Name of dropped feature in the dataset */
    name?: string;
    /** Reason the feature was dropped */
    reason?: "highly_correlated" | "has_target_leakage" | "is_date_engineered" | "feature_with_low_importance";
};
/**
 * Description of this entity
 */
type EntityDescription = string;
/**
 * ID of this entity
 */
type EntityId = string;
/**
 * Name of this entity
 */
type EntityName = string;
type EnumSortAliases = "name" | "+name" | "-name";
type EnumSortBatchPredictions = "createdAt" | "+createdAt" | "-createdAt" | "description" | "+description" | "-description" | "name" | "+name" | "-name" | "updatedAt" | "+updatedAt" | "-updatedAt";
type EnumSortDeployments = "createdAt" | "+createdAt" | "-createdAt" | "name" | "+name" | "-name" | "updatedAt" | "+updatedAt" | "-updatedAt";
type EnumSortExperimentVersions = "createdAt" | "+createdAt" | "-createdAt" | "description" | "+description" | "-description" | "experimentMode" | "+experimentMode" | "-experimentMode" | "experimentType" | "+experimentType" | "-experimentType" | "name" | "+name" | "-name" | "status" | "+status" | "-status" | "updatedAt" | "+updatedAt" | "-updatedAt" | "versionNumber" | "+versionNumber" | "-versionNumber";
type EnumSortExperiments = "createdAt" | "+createdAt" | "-createdAt" | "description" | "+description" | "-description" | "name" | "+name" | "-name" | "updatedAt" | "+updatedAt" | "-updatedAt";
type EnumSortModels = "createdAt" | "+createdAt" | "-createdAt" | "description" | "+description" | "-description" | "name" | "+name" | "-name" | "updatedAt" | "+updatedAt" | "-updatedAt";
/**
 * JSON string of error object
 */
type ErrorMessage = string;
/**
 * JSON string with list of error objects
 */
type Errors = APIError[];
/**
 * An AutoML experiment
 */
type Experiment = {
    /** Timestamp when this was created */
    createdAt: CreatedAt;
    /** Description of this entity */
    description?: EntityDescription;
    /** ID of this entity */
    id: EntityId;
    /** Name of this entity */
    name?: EntityName;
    /** ID of owner/user for this entity */
    ownerId: OwnerId;
    /** Space ID for this entity (empty string for personal space) */
    spaceId: SpaceId;
    /** Tenant ID for this entity */
    tenantId: TenantId;
    /** Timestamp when this was updated */
    updatedAt: UpdatedAt;
};
type ExperimentFindResponse = {
    data: {
        /** An AutoML experiment */
        attributes: Experiment;
        /** ID of this entity */
        id: EntityId;
        type: "experiment";
    }[];
    /** Resource links included in paginated responses */
    links: ResponseLinks;
    /** Meta for FIND operations */
    meta?: FindResponseMeta;
};
type ExperimentGetResponse = {
    data: {
        /** An AutoML experiment */
        attributes: Experiment;
        /** ID of this entity */
        id: EntityId;
        type: "experiment";
    };
};
/**
 * ID of the experiment
 */
type ExperimentId = string;
/**
 * Input for creating this entity
 */
type ExperimentInput = {
    /** Data container for ExperimentInput */
    data?: {
        /** Experiment input attributes */
        attributes?: {
            /** Description of this entity */
            description?: EntityDescription;
            /** Name of this entity */
            name: EntityName;
            /** Space ID for this entity (empty string for personal space) */
            spaceId: SpaceId;
        };
        type?: "experiment";
    };
};
/**
 * The model training mode for the experiment version
 */
type ExperimentMode = "intelligent" | "manual" | "manual_hpo";
/**
 * @example
 * [
 *   {
 *     op: "replace",
 *     path: "/name"
 *   },
 *   {
 *     op: "replace",
 *     path: "/description"
 *   },
 *   {
 *     op: "replace",
 *     path: "/spaceId"
 *   }
 * ]
 */
type ExperimentPatch = ExperimentPatchItem[];
/**
 * Experiment fields that can be patched. The following paths all require `value` to be a string: `/name`, `/spaceId`, and `/description`
 */
type ExperimentPatchItem = {
    /** All patch requests use the replace operation */
    op: "replace";
    /** Path for the property you want to update */
    path: "/name" | "/description" | "/spaceId";
    /** Use for fields that can be `any` type (string, number, etc.) */
    value: AnyType;
};
type ExperimentPostResponse = {
    data: {
        /** An AutoML experiment */
        attributes: Experiment;
        /** ID of this entity */
        id: EntityId;
        type: "experiment";
    };
};
/**
 * Experiment type
 */
type ExperimentType = "binary" | "multiclass" | "regression" | "timeseries";
/**
 * An AutoML experiment version. This is a configuration for training
 * models within an experiment.
 */
type ExperimentVersion = {
    /** List of algorithms selected for model training in this version */
    algorithms?: ModelAlgorithm[];
    /** Timestamp when this was created */
    createdAt: CreatedAt;
    /** ID of owner/user for this entity */
    createdByUserId: OwnerId;
    /** The Qlik catalog dataset ID */
    dataSetId: DataSetId;
    /** Whether this is a new or other dataset */
    datasetOrigin?: DatasetOrigin;
    /** A optional date column name to index */
    dateIndexes?: DateIndexes;
    /** JSON string of error object */
    errorMessage?: ErrorMessage;
    /** JSON string with list of error objects */
    errors?: Errors;
    /** ID of the experiment */
    experimentId: ExperimentId;
    /** The model training mode for the experiment version */
    experimentMode?: ExperimentMode;
    /** Experiment type */
    experimentType: ExperimentType;
    /** List of features from your dataset for creating Experiment
     * Versions. This appears in from ProfileInsights response (in the
     * defaultVersionConfig). You can adjust the default settings before
     * using it as input to create or update Experiment Versions. */
    featuresList?: FeaturesList;
    /** ID of this entity */
    id: EntityId;
    /** Number of the last batch */
    lastBatchNum?: number;
    /** Name of this entity */
    name?: EntityName;
    /** Pipeline metadata including transformations to apply to columns and
     * specific schema configuration data */
    pipeline?: Pipeline;
    /** Preprocessed insights. Like feature insights but with fewer details. */
    preprocessedInsights?: PreprocessedInsightColumn[];
    /** ID of the dataset profile with metadata about source data */
    profileId?: string;
    /** Current status of this entity */
    status: "ready" | "error" | "cancelled" | "pending" | "dataprep_requested" | "datasync_requested" | "datasync_done";
    /** The target field in the dataset */
    target: string;
    /** ID of the top model (based on training scores) in this experiment
     * version */
    topModelId?: string;
    /** Training duration in seconds. If provided, minimum is 900 (15m) and
     * max is 21600 (6h). */
    trainingDuration?: TrainingDuration;
    /** Timestamp when this was updated */
    updatedAt: UpdatedAt;
    /** 1-based sequential version number within the experiment */
    versionNumber?: number;
};
type ExperimentVersionFindResponse = {
    data: {
        /** An AutoML experiment version. This is a configuration for training
         * models within an experiment. */
        attributes: ExperimentVersion;
        /** ID of this entity */
        id: EntityId;
        type: "experiment-version";
    }[];
    /** Resource links included in paginated responses */
    links: ResponseLinks;
    /** Meta for FIND operations */
    meta?: FindResponseMeta;
};
type ExperimentVersionGetResponse = {
    data: {
        /** An AutoML experiment version. This is a configuration for training
         * models within an experiment. */
        attributes: ExperimentVersion;
        /** ID of this entity */
        id: EntityId;
        type: "experiment-version";
    };
};
/**
 * ID of the experiment version
 */
type ExperimentVersionId = string;
/**
 * Input for creating a new experiment version. Defaults provided in the
 * ProfileInsights response.
 */
type ExperimentVersionInput = {
    data: {
        attributes: {
            /** Algorithms used for model training in this version. See
             * documentation for valid algorithms for each
             * `experimentType`.
             *
             * If not provided, defaults to all valid algorithms for your
             * experimentType. */
            algorithms?: ModelAlgorithm[];
            /** The Qlik catalog dataset ID */
            dataSetId: DataSetId;
            /** Whether this is a new or other dataset */
            datasetOrigin?: DatasetOrigin;
            /** A optional date column name to index */
            dateIndexes?: DateIndexes;
            /** The model training mode for the experiment version */
            experimentMode: ExperimentMode;
            /** Experiment type */
            experimentType: ExperimentType;
            /** List of features from your dataset for creating Experiment
             * Versions. This appears in from ProfileInsights response (in the
             * defaultVersionConfig). You can adjust the default settings before
             * using it as input to create or update Experiment Versions. */
            featuresList: FeaturesList;
            name: string;
            /** Pipeline metadata including transformations to apply to columns and
             * specific schema configuration data */
            pipeline?: Pipeline;
            /** The target field in the dataset. Set in first experiment
             * version and can't be changed in subsequent versions. */
            target: string;
            /** Training duration in seconds. If provided, minimum is 900 (15m) and
             * max is 21600 (6h). */
            trainingDuration?: TrainingDuration;
        };
        type: "experiment-version";
    };
};
type ExperimentVersionPatch = {
    /** All patch requests use the replace operation */
    op: "replace";
    /** Path for the properties you can update. */
    path: "/name";
    /** Use for fields that can be `any` type (string, number, etc.) */
    value: AnyType;
}[];
type ExperimentVersionPostResponse = {
    data: {
        /** An AutoML experiment version. This is a configuration for training
         * models within an experiment. */
        attributes: ExperimentVersion;
        /** ID of this entity */
        id: EntityId;
        type: "experiment-version";
    };
};
type Failure = {
    errors: APIError[];
};
/**
 * A feature (column) from your dataset
 */
type Feature = {
    /** Indicates if you want to change the featureType for this
     * feature within the experiment version */
    changeType?: ChangeType;
    /** The data type of this feature in your dataset */
    dataType?: DataType;
    /** The default feature type based on the feature's data type.
     * If you want a value to be interpreted differently (e.g. 0/1
     * as categorical/boolean instead of numeric), use `changeType`. */
    featureType?: FeatureType;
    /** Include this feature in your experiment version? Default
     * here is based on insights for this feature
     * (e.g. willBeDropped). */
    include?: boolean;
    /** Name of the feature column */
    name?: string;
    /** The parent feature name for engineered features. e.g. `OrderDate` may be the parent of its engineered features (features extracted from parent) like `OrderDate.YEAR`, `OrderDate.MONTH`, etc. */
    parentFeature?: string;
};
/**
 * Metadata about the features in your dataset, generated when you create
 * ProfileInsights.
 */
type FeatureInsights = {
    /** Whether a feature cannot be the target field */
    cannotBeTarget: boolean;
    /** The default feature type based on the feature's data type.
     * If you want a value to be interpreted differently (e.g. 0/1
     * as categorical/boolean instead of numeric), use `changeType`. */
    defaultFeatureType?: FeatureType;
    /** Preliminary list of engineered features as strings. If subsequent
     * processing validates them, they'll be converted to EngineeredFeature
     * objects within a NestedColumn, each of which may contain its own
     * FeatureInsights. */
    engineeredFeatures?: string[];
    /** Experiment types in this feature insight */
    experimentTypes: ExperimentType[];
    /** List of insights about this feature. */
    insights: Insights[];
    /** Name of the feature insight */
    name: string;
    /** Whether this feature will be dropped. Traits like high cardinality
     * make some features less predictive or too costly to merit use. */
    willBeDropped: boolean;
};
/**
 * The default feature type based on the feature's data type.
 * If you want a value to be interpreted differently (e.g. 0/1
 * as categorical/boolean instead of numeric), use `changeType`.
 */
type FeatureType = "categorical" | "numeric" | "date" | "freetext";
/**
 * List of features from your dataset for creating Experiment
 * Versions. This appears in from ProfileInsights response (in the
 * defaultVersionConfig). You can adjust the default settings before
 * using it as input to create or update Experiment Versions.
 */
type FeaturesList = Feature[];
/**
 * Dataset file type
 * @example
 * "qvd, parquet, csv"
 */
type FileType = string;
/**
 * Meta for FIND operations
 */
type FindResponseMeta = {
    count: number;
};
/**
 * A optional column name upon which to create an index. Must be unique for
 * every row. If not included, Qlik will create a unique index column.
 */
type IndexColumn = string;
/**
 * Insights about a feature, such as why it's not included in a model
 */
type Insights = "constant" | "high_cardinality" | "high_cardinality_integer" | "too_many_nulls" | "will_be_impact_encoded" | "will_be_one_hot_encoded" | "possible_free_text_encoded" | "valid_index" | "underrepresented_class" | "invalid_column_name" | "will_be_date_engineered" | "possible_date_index" | "possible_group" | "possible_future_feature";
/**
 * The type for this job
 */
type JobType = "prediction";
/**
 * A model based on an algorithm within an experiment version.
 */
type Model = {
    /** Model algorithm name abbreviation */
    algoAbbrv?: ModelAlgorithmAbbreviation;
    /** The algorithm used by this model */
    algorithm?: string;
    anomalyRatio?: number;
    /** Batch number indicates the index of the experiment version fold
     * (most relevant when HPO is enabled) */
    batchNum?: number;
    binaryImbalanceSampling?: BinaryImbalanceSampling;
    binningFeatures?: string[];
    /** Dataset columns selected as features */
    columns?: string[];
    /** Timestamp when this was created */
    createdAt?: CreatedAt;
    /** Description of this entity */
    description?: EntityDescription;
    /** Features dropped because they're unsuitable */
    droppedFeatures?: DroppedFeature[];
    /** JSON string of error object */
    errorMessage?: ErrorMessage;
    /** JSON string with list of error objects */
    errors?: Errors;
    /** ID of the experiment version */
    experimentVersionId?: ExperimentVersionId;
    /** Version number of the hyperparameter optimization */
    hpoNum?: number;
    /** ID of this entity */
    id?: EntityId;
    /** Model metrics based on the type of model */
    metrics?: ModelMetrics;
    /** Model state. These are the state of the model in relation to
     * deployments. */
    modelState?: ModelState;
    /** Name of this entity */
    name?: EntityName;
    powerTransformFeatures?: string[];
    /** Ratio of sample data in relation to the dataset */
    samplingRatio?: number;
    /** Model sequence number within the experiment version */
    seqNum?: number;
    /** Model status. These are the status of the model in relation to
     * experiments (i.e. training status). */
    status?: ModelStatus;
    /** Timestamp when this was updated */
    updatedAt?: UpdatedAt;
};
/**
 * Enumeration of model algorithms.
 *
 * A subset of these may be provided based on your ExperimentType. This is
 * based on your target's featureType. When you select a target feature
 * from your ProfileInsights response (defaultVersionConfig.featuresList),
 * it tells you which algorithms will be available if you choose it as your
 * target.
 */
type ModelAlgorithm = "catboost_classifier" | "catboost_regression" | "elasticnet_regression" | "gaussian_nb" | "kneighbors_classifier" | "lasso_regression" | "lasso" | "lgbm_classifier" | "lgbm_regression" | "linear_regression" | "logistic_regression" | "random_forest_classifier" | "random_forest_regression" | "sgd_regression" | "xgb_classifier" | "xgb_regression" | "deepar_timeseries" | "mixer_timeseries" | "tft_timeseries" | "tide_timeseries";
/**
 * Model algorithm name abbreviation
 */
type ModelAlgorithmAbbreviation = "CATBC" | "CATBR" | "ELNC" | "GNBC" | "LGBMC" | "LGBMR" | "LINR" | "LOGC" | "LSOC" | "RAFC" | "RAFR" | "SGDR" | "XGBC" | "XGBR" | "DEAR" | "MIXR" | "TFTT" | "TIDE";
type ModelFindResponse = {
    data: {
        /** A model based on an algorithm within an experiment version. */
        attributes: Model;
        /** ID of this entity */
        id: EntityId;
        type: "model";
    }[];
    /** Resource links included in paginated responses */
    links: ResponseLinks;
    /** Meta for FIND operations */
    meta?: FindResponseMeta;
};
type ModelGetResponse = {
    data: {
        /** A model based on an algorithm within an experiment version. */
        attributes: Model;
        /** ID of this entity */
        id: EntityId;
        type: "model";
    };
};
/**
 * ID of the model
 */
type ModelId = string;
/**
 * Model information stored on an alias
 */
type ModelInfo = {
    /** ID of this entity */
    id?: EntityId;
};
/**
 * Model metrics based on the type of model
 */
type ModelMetrics = {
    /** Binary metrics for categorical values with two options. Details:
     * https://help.qlik.com/en-US/cloud-services/Subsystems/Hub/Content/Sense_Hub/AutoML/scoring-binary-classification.htm */
    binary?: ModelMetricsBinary;
    /** Multiclass metrics for categorical values with 3+ options. Details:
     * https://help.qlik.com/en-US/cloud-services/Subsystems/Hub/Content/Sense_Hub/AutoML/scoring-multiclass-classification.htm */
    multiclass?: ModelMetricsMulticlass;
    /** Regression metrics for numeric values. Details:
     * https://help.qlik.com/en-US/cloud-services/Subsystems/Hub/Content/Sense_Hub/AutoML/scoring-regression.htm */
    regression?: ModelMetricsRegression;
};
/**
 * Binary metrics for categorical values with two options. Details:
 * https://help.qlik.com/en-US/cloud-services/Subsystems/Hub/Content/Sense_Hub/AutoML/scoring-binary-classification.htm
 */
type ModelMetricsBinary = {
    /** Average measure of how often the model made correct predictions
     * (training data) */
    accuracy?: number;
    /** Average measure of how often the model made correct predictions
     * (test data) */
    accuracyTest?: number;
    /** Area under curve (training data) */
    auc?: number;
    /** Area under curve (test data) */
    aucTest?: number;
    /** The harmonic mean of precision and recall for training data */
    f1?: number;
    /** The harmonic mean of precision and recall for test data */
    f1Test?: number;
    /** The false positive rate (training data) */
    fallout?: number;
    /** The false positive rate (test data) */
    falloutTest?: number;
    /** Actual true values incorrectly predicted as false (training data) */
    falseNegative?: number;
    /** Actual true values incorrectly predicted as false (test data) */
    falseNegativeTest?: number;
    /** Actual false values incorrectly predicted as true (training data) */
    falsePositive?: number;
    /** Actual false values incorrectly predicted as true (test data) */
    falsePositiveTest?: number;
    /** Measures accuracy in logistic regression (training data) */
    logLoss?: number;
    /** Measures accuracy in logistic regression (test data) */
    logLossTest?: number;
    /** Matthews correlation coefficient (training data) */
    mcc?: number;
    /** Matthews correlation coefficient (test data) */
    mccTest?: number;
    /** The false negative rate (training data) */
    missRate?: number;
    /** The false negative rate (test data) */
    missRateTest?: number;
    /** Negative predictive value (training data) */
    npv?: number;
    /** Negative predictive value (test data) */
    npvTest?: number;
    /** Positive predictive value. Probability that the model was correct
     * when it predicted something was true. (training data) */
    precision?: number;
    /** Positive predictive value. Probability that the model was correct
     * when it predicted something was true. (test data) */
    precisionTest?: number;
    /** The true positive rate (training data) */
    recall?: number;
    /** The true positive rate (test data) */
    recallTest?: number;
    /** The true negative rate (training data) */
    specificity?: number;
    /** The true negative rate (test data) */
    specificityTest?: number;
    /** Probability that a prediction is true (training data) */
    threshold?: number;
    /** Probability that a prediction is true (test data) */
    thresholdTest?: number;
    /** Actual false values correctly predicted as false (training data) */
    trueNegative?: number;
    /** Actual false values correctly predicted as false (test data) */
    trueNegativeTest?: number;
    /** Actual true values correctly predicted as true (training data) */
    truePositive?: number;
    /** Actual true values correctly predicted as true (test data) */
    truePositiveTest?: number;
};
/**
 * Multiclass metrics for categorical values with 3+ options. Details:
 * https://help.qlik.com/en-US/cloud-services/Subsystems/Hub/Content/Sense_Hub/AutoML/scoring-multiclass-classification.htm
 */
type ModelMetricsMulticlass = {
    /** Average of how often the model made a correct prediction (training
     * data) */
    accuracy?: number;
    /** Average of how often the model made a correct prediction (test data) */
    accuracyTest?: number;
    /** A matrix summary of the accuracy of predictions in a classification
     * model (training data) */
    confusionMatrix?: string;
    /** A matrix summary of the accuracy of predictions in a classification
     * model (training data) */
    confusionMatrixTest?: string;
    /** Macro F1 is the averaged F1 value for each class without weighting
     * (training data) */
    f1Macro?: number;
    /** Macro F1 is the averaged F1 value for each class without weighting
     * (test data) */
    f1MacroTest?: number;
    /** Micro F1 is the F1 value calculated across the entire confusion
     * matrix (training data) */
    f1Micro?: number;
    /** Micro F1 is the F1 value calculated across the entire confusion
     * matrix (test data) */
    f1MicroTest?: number;
    /** Weighted F1 (training data) */
    f1Weighted?: number;
    /** Weighted F1 (test data) */
    f1WeightedTest?: number;
};
/**
 * Regression metrics for numeric values. Details:
 * https://help.qlik.com/en-US/cloud-services/Subsystems/Hub/Content/Sense_Hub/AutoML/scoring-regression.htm
 */
type ModelMetricsRegression = {
    /** Mean absolute error (training data) */
    mae?: number;
    /** Mean absolute error (test data) */
    maeTest?: number;
    /** Mean squared error (training data) */
    mse?: number;
    /** Mean squared error (test data) */
    mseTest?: number;
    /** R squared (training data) */
    r2?: number;
    /** R squared (test data) */
    r2Test?: number;
    /** Root mean squared error (training data) */
    rmse?: number;
    /** Root mean squared error (test data) */
    rmseTest?: number;
};
/**
 * Model state. These are the state of the model in relation to
 * deployments.
 */
type ModelState = "pending" | "enabled" | "disabled" | "inactive";
/**
 * Model status. These are the status of the model in relation to
 * experiments (i.e. training status).
 */
type ModelStatus = "pending" | "training_requested" | "training_done" | "ready" | "error";
type ModelsInfo = ModelInfo[];
type OutputFile = {
    fileName: string;
    /** Dataset file type */
    fileType: FileType;
    key: string;
    path: string;
    /** Space ID for this entity (empty string for personal space) */
    spaceId: SpaceId;
};
/**
 * ID of owner/user for this entity
 */
type OwnerId = string;
/**
 * ID of the current job's parent
 */
type ParentJobId = string;
/**
 * Pipeline metadata including transformations to apply to columns and
 * specific schema configuration data
 */
type Pipeline = {
    dataSchemaConfiguration?: DataSchemaConfiguration[];
    transforms?: Transform[];
};
type PredictionJobResponse = {
    /** The ID of a correlated resource of corrType */
    corrId: CorrId;
    /** Types names of correlated resources (batch 'prediction' and
     * experiment_version) */
    corrType: CorrType;
    /** Timestamp when this was created */
    createdAt: CreatedAt;
    /** ID of the owner/user that created this entity */
    createdBy: string;
    /** Timestamp when this is deleted */
    deletedAt: DeletedAt;
    /** ID of a model deployment */
    deploymentId: DeploymentId;
    details: {
        isScheduled: boolean;
        lineageSchemaUpdated: boolean;
        outputFiles: OutputFile[];
    };
    experimentVersionNumber: string;
    /** ID of this entity */
    id: EntityId;
    /** The type for this job */
    jobType: JobType;
    /** ID of the model */
    modelId: ModelId;
    name: string;
    /** ID of the current job's parent */
    parentJobId: ParentJobId;
    parentName: string;
    rowsPredicted: number;
    /** Status of this job */
    status: "pending" | "completed" | "cancelled" | "error";
    success: boolean;
    /** Tenant ID for this entity */
    tenantId: TenantId;
    trigger: string;
    /** Timestamp when this was updated */
    updatedAt: UpdatedAt;
};
/**
 * Metadata about features/columns from dataset after preprocessing
 */
type PreprocessedInsightColumn = {
    /** Preliminary list of column/feature insights available after
     * preprocessing but before feature insights are available */
    insights: ("is_free_text" | "cannot_be_processed_as_free_text" | "is_date_engineered" | "has_target_leakage" | "feature_type_change_invalid" | "feature_type_change_failed" | "feature_type_change_successful")[];
    /** Name of the preprocessed insight column */
    name: string;
    /** Whether this feature insight will be dropped due to free text or
     * high cardinality that makes it less useful */
    willBeDropped: boolean;
};
/**
 * Insights (metadata) about an experiment dataset
 */
type ProfileInsights = {
    /** List of algorithms available for the selected experiment type */
    algorithms?: ModelAlgorithm[];
    defaultVersionConfig?: {
        /** The Qlik catalog dataset ID */
        dataSetId: DataSetId;
        /** Whether this is a new or other dataset */
        datasetOrigin: DatasetOrigin;
        /** The model training mode for the experiment version */
        experimentMode: ExperimentMode;
        /** List of features from your dataset for creating Experiment
         * Versions. This appears in from ProfileInsights response (in the
         * defaultVersionConfig). You can adjust the default settings before
         * using it as input to create or update Experiment Versions. */
        featuresList?: FeaturesList;
        name: string;
    };
    /** List of feature insights object, one per feature in the dataset */
    insights?: FeatureInsights[];
    /** ID of owner/user for this entity */
    ownerId: OwnerId;
    /** Status of profile insights. Not available until `ready`. */
    status: "pending" | "error" | "ready";
    /** Tenant ID for this entity */
    tenantId: TenantId;
};
type ProfileInsightsGetResponse = {
    data: {
        /** Insights (metadata) about an experiment dataset */
        attributes: ProfileInsights;
        /** ID of this entity */
        id: EntityId;
        type: "profile-insights";
    };
};
/**
 * Input to get dataset and feature metadata needed to create
 * experiment versions
 */
type ProfileInsightsInput = {
    /** Data wrapper for request input */
    data?: {
        /** The request body for this resource */
        attributes?: {
            /** The Qlik catalog dataset ID */
            dataSetId?: DataSetId;
            /** Experiment type */
            experimentType?: ExperimentType;
            /** Whether the server should or client should manage polling/waiting */
            shouldWait?: boolean;
            /** Optional selected target provided on subsequent requests */
            target?: string;
        };
        type?: "profile-insights";
    };
};
type RealTimePredictionInputSchema = {
    /** The name of a feature in the dataset */
    name?: string;
};
type RealTimePredictionSchema = {
    /** The name of a feature in the dataset */
    name?: string;
};
/**
 * Input values for creating realtime predictions
 */
type RealtimePrediction = {
    data?: {
        attributes?: {
            /** Rows of the dataset from which to produce predictions */
            rows?: string[][];
            /** List of features in the dataset */
            schema?: RealTimePredictionSchema[];
        };
        type?: "realtime-prediction";
    };
};
/**
 * Input values for creating realtime predictions
 */
type RealtimePredictionInput = {
    /** Rows of the dataset from which to produce predictions.
     * Date features must be in ISO 8601 format. */
    rows?: string[][];
    /** List of features in the dataset. */
    schema?: RealTimePredictionInputSchema[];
};
/**
 * Resource links included in paginated responses
 */
type ResponseLinks = {
    first: {
        /** Link to the first set of responses from `offset` 0 to count `limit`` */
        href?: string;
    };
    last: {
        /** Link to the last set of responses from `limit` minus `offset` to
         * `limit` */
        href?: string;
    };
    next: {
        /** Link to the next set of responses */
        href?: string;
    };
    prev: {
        /** Link to the previous set of responses */
        href?: string;
    };
    self: {
        /** Link to the current set of responses */
        href?: string;
    };
};
/**
 * Space ID for this entity (empty string for personal space)
 */
type SpaceId = string;
/**
 * Tenant ID for this entity
 */
type TenantId = string;
/**
 * Training duration in seconds. If provided, minimum is 900 (15m) and
 * max is 21600 (6h).
 */
type TrainingDuration = number;
type Transform = {
    column?: ColumnTransform;
};
/**
 * Timestamp when this was updated
 */
type UpdatedAt = string;
/**
 * List deployments
 * @example
 * getMlDeployments(
 *   {
 *     filter: "`filter=spaceId eq \"UUID\" and modelState eq \"enabled\"`",
 *     limit: 10,
 *     offset: 32
 *   }
 * )
 *
 * @param query an object with query parameters
 * @throws GetMlDeploymentsHttpError
 */
declare const getMlDeployments: (query: {
    /** Deployment fields by which you can filter responses.<br><br>
     * - `spaceId` ID string (or empty string for personal space) - ID of space in which deployment(s) exist
     * - `modelId` UUID string - By model ID
     * - `createdBy` ID string
     * - `ownerId` ID string
     * - `approverId` ID string - ID of user that approved a model in the deployment
     * - `experimentId` UUID string - ID of experiment in which model(s) exist
     * - `experimentVersionId` UUID string - ID of experiment version in which model(s) exist
     * - `predictionEnabled` boolean - Are predictions enabled
     * - `exactName` string - Deployments with exact name. Names may not be unique.
     * - `nameContains` string - Deployments where name includes this. Names may not be unique
     * - `modelName` string - Partial or exact, case-insensitive name of model in the deployment
     * - `modelState` enum string - State by which to find models<br><br>
     *   - Valid states: `pending, enabled, disabled, inactive` */
    filter?: string;
    /** Number of results per page. Default is 32. */
    limit?: number;
    /** Number of rows to skip before getting page[size] */
    offset?: number;
    /** Field(s) by which to sort response */
    sort?: EnumSortDeployments;
}, options?: ApiCallOptions) => Promise<GetMlDeploymentsHttpResponse>;
type GetMlDeploymentsHttpResponse = {
    data: DeploymentFindResponse;
    headers: Headers;
    status: 200;
    prev?: (options?: ApiCallOptions) => Promise<GetMlDeploymentsHttpResponse>;
    next?: (options?: ApiCallOptions) => Promise<GetMlDeploymentsHttpResponse>;
};
type GetMlDeploymentsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Create a deployment
 *
 * @param body an object with the body content
 * @throws CreateMlDeploymentHttpError
 */
declare const createMlDeployment: (body: DeploymentInput, options?: ApiCallOptions) => Promise<CreateMlDeploymentHttpResponse>;
type CreateMlDeploymentHttpResponse = {
    data: DeploymentPostResponse;
    headers: Headers;
    status: 201;
};
type CreateMlDeploymentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Delete a deployment
 *
 * @param deploymentId ID of the deployment
 * @throws DeleteMlDeploymentHttpError
 */
declare const deleteMlDeployment: (deploymentId: string, options?: ApiCallOptions) => Promise<DeleteMlDeploymentHttpResponse>;
type DeleteMlDeploymentHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type DeleteMlDeploymentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Get a deployment
 *
 * @param deploymentId ID of the deployment
 * @throws GetMlDeploymentHttpError
 */
declare const getMlDeployment: (deploymentId: string, options?: ApiCallOptions) => Promise<GetMlDeploymentHttpResponse>;
type GetMlDeploymentHttpResponse = {
    data: DeploymentGetResponse;
    headers: Headers;
    status: 200;
};
type GetMlDeploymentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Update a deployment
 *
 * @param deploymentId ID of the deployment
 * @param body an object with the body content
 * @throws PatchMlDeploymentHttpError
 */
declare const patchMlDeployment: (deploymentId: string, body: DeploymentPatch, options?: ApiCallOptions) => Promise<PatchMlDeploymentHttpResponse>;
type PatchMlDeploymentHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type PatchMlDeploymentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Activate the model for this deployment
 *
 * @param deploymentId ID of the deployment
 * @throws ActivateModelsMlDeploymentHttpError
 */
declare const activateModelsMlDeployment: (deploymentId: string, options?: ApiCallOptions) => Promise<ActivateModelsMlDeploymentHttpResponse>;
type ActivateModelsMlDeploymentHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type ActivateModelsMlDeploymentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Deactivate the model for this deployment
 *
 * @param deploymentId ID of the deployment
 * @throws DeactivateModelsMlDeploymentHttpError
 */
declare const deactivateModelsMlDeployment: (deploymentId: string, options?: ApiCallOptions) => Promise<DeactivateModelsMlDeploymentHttpResponse>;
type DeactivateModelsMlDeploymentHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type DeactivateModelsMlDeploymentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Retrieves a list of aliases based on filter parameters for a deployment.
 *
 * @param deploymentId
 * @param query an object with query parameters
 * @throws GetMlDeploymentAliasesHttpError
 */
declare const getMlDeploymentAliases: (deploymentId: string, query: {
    /** Alias fields by which you can filter responses
     * - `name` string - Aliases with exact name
     * - `modelId` UUID string - By model ID
     * - `mode` enum string - Mode by which alias is set to */
    filter?: string;
    /** Number of results per page. Default is 32. */
    limit?: number;
    /** Number of rows to skip before getting page[size] */
    offset?: number;
    /** Field(s) by which to sort response */
    sort?: EnumSortAliases;
}, options?: ApiCallOptions) => Promise<GetMlDeploymentAliasesHttpResponse>;
type GetMlDeploymentAliasesHttpResponse = {
    data: AliasFindResponse;
    headers: Headers;
    status: 200;
    prev?: (options?: ApiCallOptions) => Promise<GetMlDeploymentAliasesHttpResponse>;
    next?: (options?: ApiCallOptions) => Promise<GetMlDeploymentAliasesHttpResponse>;
};
type GetMlDeploymentAliasesHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Creates an alias for a deployment.
 *
 * @param deploymentId ID of the deployment
 * @param body an object with the body content
 * @throws CreateMlDeploymentAliaseHttpError
 */
declare const createMlDeploymentAliase: (deploymentId: string, body: AliasInput, options?: ApiCallOptions) => Promise<CreateMlDeploymentAliaseHttpResponse>;
type CreateMlDeploymentAliaseHttpResponse = {
    data: AliasPostResponse;
    headers: Headers;
    status: 201;
};
type CreateMlDeploymentAliaseHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Delete an alias from a deployment.
 *
 * @param deploymentId ID of the deployment
 * @param aliasId ID of the alias
 * @throws DeleteMlDeploymentAliaseHttpError
 */
declare const deleteMlDeploymentAliase: (deploymentId: string, aliasId: string, options?: ApiCallOptions) => Promise<DeleteMlDeploymentAliaseHttpResponse>;
type DeleteMlDeploymentAliaseHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type DeleteMlDeploymentAliaseHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Retrieves an alias that exists on the deployment.
 *
 * @param deploymentId ID of the deployment
 * @param aliasId ID of the alias
 * @throws GetMlDeploymentAliaseHttpError
 */
declare const getMlDeploymentAliase: (deploymentId: string, aliasId: string, options?: ApiCallOptions) => Promise<GetMlDeploymentAliaseHttpResponse>;
type GetMlDeploymentAliaseHttpResponse = {
    data: AliasGetResponse;
    headers: Headers;
    status: 200;
};
type GetMlDeploymentAliaseHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Updates an alias for a deployment.
 *
 * @param deploymentId ID of the deployment
 * @param aliasId ID of the alias
 * @param body an object with the body content
 * @throws PatchMlDeploymentAliaseHttpError
 */
declare const patchMlDeploymentAliase: (deploymentId: string, aliasId: string, body: AliasPatch, options?: ApiCallOptions) => Promise<PatchMlDeploymentAliaseHttpResponse>;
type PatchMlDeploymentAliaseHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type PatchMlDeploymentAliaseHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Generate predictions in a synchronous request/response
 *
 * @param deploymentId ID of the deployment
 * @param aliasName The name of the ML Deployment Alias that will be used to determine which model should be used to produce predictions
 * @param query an object with query parameters
 * @param body an object with the body content
 * @throws RunMlDeploymentAliaseRealtimePredictionsHttpError
 */
declare const runMlDeploymentAliaseRealtimePredictions: (deploymentId: string, aliasName: string, query: {
    /** If true, reason why a prediction was not produced included response */
    includeNotPredictedReason?: boolean;
    /** If true, shap values included in response */
    includeShap?: boolean;
    /** If true, source data included in response */
    includeSource?: boolean;
    /** The name of the feature in the source data to use as an index in the
     * response data. The column will be included with its original name
     * and values. This is intended to allow the caller to join results
     * with source data. */
    index?: string;
}, body: RealtimePredictionInput, options?: ApiCallOptions) => Promise<RunMlDeploymentAliaseRealtimePredictionsHttpResponse>;
type RunMlDeploymentAliaseRealtimePredictionsHttpResponse = {
    data: RealtimePrediction;
    headers: Headers;
    status: 200;
};
type RunMlDeploymentAliaseRealtimePredictionsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * List batch prediction configurations
 *
 * @param deploymentId ID of the deployment
 * @param query an object with query parameters
 * @throws GetMlDeploymentBatchPredictionsHttpError
 */
declare const getMlDeploymentBatchPredictions: (deploymentId: string, query: {
    /** Batch prediction fields by which you can filter responses.<br><br>
     * - `modelId` UUID string - By model ID */
    filter?: string;
    /** Number of results per page. Default is 32. */
    limit?: number;
    /** Number of rows to skip before getting page[size] */
    offset?: number;
    /** Field(s) by which to sort response */
    sort?: EnumSortBatchPredictions;
}, options?: ApiCallOptions) => Promise<GetMlDeploymentBatchPredictionsHttpResponse>;
type GetMlDeploymentBatchPredictionsHttpResponse = {
    data: BatchPredictionFindResponse;
    headers: Headers;
    status: 200;
    prev?: (options?: ApiCallOptions) => Promise<GetMlDeploymentBatchPredictionsHttpResponse>;
    next?: (options?: ApiCallOptions) => Promise<GetMlDeploymentBatchPredictionsHttpResponse>;
};
type GetMlDeploymentBatchPredictionsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Create a prediction configuration
 *
 * @param deploymentId ID of the deployment
 * @param body an object with the body content
 * @throws CreateMlDeploymentBatchPredictionHttpError
 */
declare const createMlDeploymentBatchPrediction: (deploymentId: string, body: BatchPredictionInput, options?: ApiCallOptions) => Promise<CreateMlDeploymentBatchPredictionHttpResponse>;
type CreateMlDeploymentBatchPredictionHttpResponse = {
    data: BatchPredictionPostResponse;
    headers: Headers;
    status: 201;
};
type CreateMlDeploymentBatchPredictionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Delete a batch prediction
 *
 * @param deploymentId ID of the deployment
 * @param batchPredictionId ID of the batch prediction
 * @throws DeleteMlDeploymentBatchPredictionHttpError
 */
declare const deleteMlDeploymentBatchPrediction: (deploymentId: string, batchPredictionId: string, options?: ApiCallOptions) => Promise<DeleteMlDeploymentBatchPredictionHttpResponse>;
type DeleteMlDeploymentBatchPredictionHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type DeleteMlDeploymentBatchPredictionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Retrieve a batch prediction
 *
 * @param deploymentId ID of the deployment
 * @param batchPredictionId ID of the batch prediction
 * @throws GetMlDeploymentBatchPredictionHttpError
 */
declare const getMlDeploymentBatchPrediction: (deploymentId: string, batchPredictionId: string, options?: ApiCallOptions) => Promise<GetMlDeploymentBatchPredictionHttpResponse>;
type GetMlDeploymentBatchPredictionHttpResponse = {
    data: BatchPredictionGetResponse;
    headers: Headers;
    status: 200;
};
type GetMlDeploymentBatchPredictionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Updates a batch prediction
 *
 * @param deploymentId ID of the deployment
 * @param batchPredictionId ID of the batch prediction
 * @param body an object with the body content
 * @throws PatchMlDeploymentBatchPredictionHttpError
 */
declare const patchMlDeploymentBatchPrediction: (deploymentId: string, batchPredictionId: string, body: BatchPredictionPatch, options?: ApiCallOptions) => Promise<PatchMlDeploymentBatchPredictionHttpResponse>;
type PatchMlDeploymentBatchPredictionHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type PatchMlDeploymentBatchPredictionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Run a batch prediction
 *
 * @param deploymentId ID of the deployment
 * @param batchPredictionId ID of the batch prediction
 * @throws PredictMlDeploymentBatchPredictionHttpError
 */
declare const predictMlDeploymentBatchPrediction: (deploymentId: string, batchPredictionId: string, options?: ApiCallOptions) => Promise<PredictMlDeploymentBatchPredictionHttpResponse>;
type PredictMlDeploymentBatchPredictionHttpResponse = {
    data: BatchPredictionActionResponse;
    headers: Headers;
    status: 202;
};
type PredictMlDeploymentBatchPredictionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Deletes the schedule from a batch prediction.
 *
 * @param deploymentId ID of the deployment
 * @param batchPredictionId ID of the batch prediction
 * @throws DeleteMlDeploymentBatchPredictionScheduleHttpError
 */
declare const deleteMlDeploymentBatchPredictionSchedule: (deploymentId: string, batchPredictionId: string, options?: ApiCallOptions) => Promise<DeleteMlDeploymentBatchPredictionScheduleHttpResponse>;
type DeleteMlDeploymentBatchPredictionScheduleHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type DeleteMlDeploymentBatchPredictionScheduleHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Retrieves the schedule for a batch prediction.
 *
 * @param deploymentId ID of the deployment
 * @param batchPredictionId ID of the batch prediction
 * @throws GetMlDeploymentBatchPredictionScheduleHttpError
 */
declare const getMlDeploymentBatchPredictionSchedule: (deploymentId: string, batchPredictionId: string, options?: ApiCallOptions) => Promise<GetMlDeploymentBatchPredictionScheduleHttpResponse>;
type GetMlDeploymentBatchPredictionScheduleHttpResponse = {
    data: BatchPredictionScheduleGetResponse;
    headers: Headers;
    status: 200;
};
type GetMlDeploymentBatchPredictionScheduleHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Updates the schedule for a batch prediction.
 *
 * @param deploymentId ID of the deployment
 * @param batchPredictionId ID of the batch prediction
 * @param body an object with the body content
 * @throws UpdateMlDeploymentBatchPredictionScheduleHttpError
 */
declare const updateMlDeploymentBatchPredictionSchedule: (deploymentId: string, batchPredictionId: string, body: BatchPredictionSchedulePatch, options?: ApiCallOptions) => Promise<UpdateMlDeploymentBatchPredictionScheduleHttpResponse>;
type UpdateMlDeploymentBatchPredictionScheduleHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type UpdateMlDeploymentBatchPredictionScheduleHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Adds a schedule to a batch prediction.
 *
 * @param deploymentId ID of the deployment
 * @param batchPredictionId ID of the batch prediction
 * @param body an object with the body content
 * @throws SetMlDeploymentBatchPredictionScheduleHttpError
 */
declare const setMlDeploymentBatchPredictionSchedule: (deploymentId: string, batchPredictionId: string, body: BatchPredictionScheduleInput, options?: ApiCallOptions) => Promise<SetMlDeploymentBatchPredictionScheduleHttpResponse>;
type SetMlDeploymentBatchPredictionScheduleHttpResponse = {
    data: BatchPredictionSchedulePutResponse;
    headers: Headers;
    status: 201;
};
type SetMlDeploymentBatchPredictionScheduleHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Add deployed models for this deployment
 *
 * @param deploymentId ID of the deployment
 * @param body an object with the body content
 * @throws AddMlDeploymentModelsHttpError
 */
declare const addMlDeploymentModels: (deploymentId: string, body: DeployedModelsInput, options?: ApiCallOptions) => Promise<AddMlDeploymentModelsHttpResponse>;
type AddMlDeploymentModelsHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type AddMlDeploymentModelsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Remove deployed models from this deployment
 *
 * @param deploymentId ID of the deployment
 * @param body an object with the body content
 * @throws RemoveMlDeploymentModelsHttpError
 */
declare const removeMlDeploymentModels: (deploymentId: string, body: DeployedModelsInput, options?: ApiCallOptions) => Promise<RemoveMlDeploymentModelsHttpResponse>;
type RemoveMlDeploymentModelsHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type RemoveMlDeploymentModelsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Generate predictions in a synchronous request/response
 *
 * @param deploymentId ID of the deployment
 * @param query an object with query parameters
 * @param body an object with the body content
 * @throws RunMlDeploymentRealtimePredictionsHttpError
 */
declare const runMlDeploymentRealtimePredictions: (deploymentId: string, query: {
    /** If true, reason why a prediction was not produced included response */
    includeNotPredictedReason?: boolean;
    /** If true, shapley values included in response */
    includeShap?: boolean;
    /** If true, source data included in response */
    includeSource?: boolean;
    /** The name of the feature in the source data to use as an index in the
     * response data. The column will be included with its original name
     * and values. This is intended to allow the caller to join results
     * with source data. */
    index?: string;
}, body: RealtimePredictionInput, options?: ApiCallOptions) => Promise<RunMlDeploymentRealtimePredictionsHttpResponse>;
type RunMlDeploymentRealtimePredictionsHttpResponse = {
    data: RealtimePrediction;
    headers: Headers;
    status: 200;
};
type RunMlDeploymentRealtimePredictionsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Retrieves a list of experiments based on provided filter and sort
 * parameters.
 * @example
 * getMlExperiments(
 *   {
 *     filter: "`filter=ownerId eq UUID and experimentVersionId eq UUID`",
 *     limit: 10,
 *     offset: 32
 *   }
 * )
 *
 * @param query an object with query parameters
 * @throws GetMlExperimentsHttpError
 */
declare const getMlExperiments: (query: {
    /** Experiment fields by which you can filter responses within this tenant
     * - `ownerId` ID string - ID of the owner/user that created the experiment
     * - `spaceId` ID string (or empty string for personal space) - ID of the space where the experiment is saved.
     * - `experimentVersionId` UUID string - ID of an experiment version in the experiment
     * - `modelId` UUID string - ID of a model associated with the experiment
     * - `deploymentId` UUID string - ID of a deployment of a model associated with the experiment */
    filter?: string;
    /** Number of results per page. Default is 32. */
    limit?: number;
    /** Number of rows to skip before getting page[size] */
    offset?: number;
    /** Field(s) by which to sort response */
    sort?: EnumSortExperiments;
}, options?: ApiCallOptions) => Promise<GetMlExperimentsHttpResponse>;
type GetMlExperimentsHttpResponse = {
    data: ExperimentFindResponse;
    headers: Headers;
    status: 200;
    prev?: (options?: ApiCallOptions) => Promise<GetMlExperimentsHttpResponse>;
    next?: (options?: ApiCallOptions) => Promise<GetMlExperimentsHttpResponse>;
};
type GetMlExperimentsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Create an experiment
 *
 * @param body an object with the body content
 * @throws CreateMlExperimentHttpError
 */
declare const createMlExperiment: (body: ExperimentInput, options?: ApiCallOptions) => Promise<CreateMlExperimentHttpResponse>;
type CreateMlExperimentHttpResponse = {
    data: ExperimentPostResponse;
    headers: Headers;
    status: 201;
};
type CreateMlExperimentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Delete an experiment
 *
 * @param experimentId ID of the experiment
 * @throws DeleteMlExperimentHttpError
 */
declare const deleteMlExperiment: (experimentId: string, options?: ApiCallOptions) => Promise<DeleteMlExperimentHttpResponse>;
type DeleteMlExperimentHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type DeleteMlExperimentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Get an experiment
 *
 * @param experimentId ID of the experiment
 * @throws GetMlExperimentHttpError
 */
declare const getMlExperiment: (experimentId: string, options?: ApiCallOptions) => Promise<GetMlExperimentHttpResponse>;
type GetMlExperimentHttpResponse = {
    data: ExperimentGetResponse;
    headers: Headers;
    status: 200;
};
type GetMlExperimentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Update an experiment
 *
 * @param experimentId ID of the experiment
 * @param body an object with the body content
 * @throws PatchMlExperimentHttpError
 */
declare const patchMlExperiment: (experimentId: string, body: ExperimentPatch, options?: ApiCallOptions) => Promise<PatchMlExperimentHttpResponse>;
type PatchMlExperimentHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type PatchMlExperimentHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * List models
 *
 * @param experimentId ID of the experiment
 * @param query an object with query parameters
 * @throws GetMlExperimentModelsHttpError
 */
declare const getMlExperimentModels: (experimentId: string, query: {
    /** Model fields you can filter by:<br><br>
     *
     * - `experimentVersionId` UUID string - Find by experiment version ID
     * - `batchNum` UUID string - Search by batch number
     * - `isHpo` boolean - Is hyperparameter optimization used?
     * - `isMetrics` boolean - Are metrics for regression, binary, or multiclass are used?
     * - `id` UUID string - Find by model ID
     * - `algorithm` enum string - Find by algorithm<br><br>
     *
     *   - Valid algorithms: catboost_classifier, catboost_regression,
     *     elasticnet_regression, gaussian_nb, kneighbors_classifier,
     *     lasso_regression, lasso, lgbm_classifier, lgbm_regression,
     *     linear_regression, logistic_regression, random_forest_classifier,
     *     random_forest_regression, sgd_regression, xgb_classifier,
     *     xgb_regression<br><br>
     *
     * - `status` enum string - find by status<br><br>
     *   - Valid statuses: pending, training_requested, training_done, ready, error<br><br>
     * - `hasDeployment` boolean - Models that are part of a deployment
     * - `nameContains` string - Models with name includes this case-insensitive string
     * - `exactName` string - Models with exact name. Model names may not be unique
     * - `samplingRatio` number - Find models by sampling ratio
     * - `modelState` enum string - State by which to find models<br><br>
     *   - Valid states: `pending, enabled, disabled, inactive` */
    filter?: string;
    /** Number of results per page. Default is 32. */
    limit?: number;
    /** Number of rows to skip before getting page[size] */
    offset?: number;
    /** Field(s) by which to sort response */
    sort?: EnumSortModels;
}, options?: ApiCallOptions) => Promise<GetMlExperimentModelsHttpResponse>;
type GetMlExperimentModelsHttpResponse = {
    data: ModelFindResponse;
    headers: Headers;
    status: 200;
    prev?: (options?: ApiCallOptions) => Promise<GetMlExperimentModelsHttpResponse>;
    next?: (options?: ApiCallOptions) => Promise<GetMlExperimentModelsHttpResponse>;
};
type GetMlExperimentModelsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Get a model
 *
 * @param experimentId ID of the experiment
 * @param modelId ID of the model
 * @throws GetMlExperimentModelHttpError
 */
declare const getMlExperimentModel: (experimentId: string, modelId: string, options?: ApiCallOptions) => Promise<GetMlExperimentModelHttpResponse>;
type GetMlExperimentModelHttpResponse = {
    data: ModelGetResponse;
    headers: Headers;
    status: 200;
};
type GetMlExperimentModelHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * List experiment versions
 *
 * @param experimentId ID of the experiment
 * @param query an object with query parameters
 * @throws GetMlExperimentVersionsHttpError
 */
declare const getMlExperimentVersions: (experimentId: string, query: {
    /** Experiment version filter options
     * - `isRunning` boolean - Is the experiment version running (training models)?
     * - `isSettled` boolean - Is the experiment version settled?
     * - `status` enum string - Status to filter by. Omit to get models of any status.
     *   - Valid statuses: pending, ready, error, cancelled
     * - `modelId` UUID string - ID of a model associated with the experiment */
    filter?: string;
    /** Number of results per page. Default is 32. */
    limit?: number;
    /** Number of rows to skip before getting page[size] */
    offset?: number;
    /** Field(s) by which to sort response */
    sort?: EnumSortExperimentVersions;
}, options?: ApiCallOptions) => Promise<GetMlExperimentVersionsHttpResponse>;
type GetMlExperimentVersionsHttpResponse = {
    data: ExperimentVersionFindResponse;
    headers: Headers;
    status: 200;
    prev?: (options?: ApiCallOptions) => Promise<GetMlExperimentVersionsHttpResponse>;
    next?: (options?: ApiCallOptions) => Promise<GetMlExperimentVersionsHttpResponse>;
};
type GetMlExperimentVersionsHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Creates an experiment version.
 * Poll this version and check its `status` field to determine when models
 * are finished training.
 *
 * @param experimentId ID of the experiment
 * @param body an object with the body content
 * @throws CreateMlExperimentVersionHttpError
 */
declare const createMlExperimentVersion: (experimentId: string, body: ExperimentVersionInput, options?: ApiCallOptions) => Promise<CreateMlExperimentVersionHttpResponse>;
type CreateMlExperimentVersionHttpResponse = {
    data: ExperimentVersionPostResponse;
    headers: Headers;
    status: 201;
};
type CreateMlExperimentVersionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Delete an experiment version
 *
 * @param experimentId ID of the experiment
 * @param experimentVersionId ID of the experiment version
 * @throws DeleteMlExperimentVersionHttpError
 */
declare const deleteMlExperimentVersion: (experimentId: string, experimentVersionId: string, options?: ApiCallOptions) => Promise<DeleteMlExperimentVersionHttpResponse>;
type DeleteMlExperimentVersionHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type DeleteMlExperimentVersionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Get an experiment version
 *
 * @param experimentId ID of the experiment
 * @param experimentVersionId ID of the experiment version
 * @throws GetMlExperimentVersionHttpError
 */
declare const getMlExperimentVersion: (experimentId: string, experimentVersionId: string, options?: ApiCallOptions) => Promise<GetMlExperimentVersionHttpResponse>;
type GetMlExperimentVersionHttpResponse = {
    data: ExperimentVersionGetResponse;
    headers: Headers;
    status: 200;
};
type GetMlExperimentVersionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Update an experiment version
 *
 * @param experimentId ID of the experiment
 * @param experimentVersionId ID of the experiment version
 * @param body an object with the body content
 * @throws PatchMlExperimentVersionHttpError
 */
declare const patchMlExperimentVersion: (experimentId: string, experimentVersionId: string, body: ExperimentVersionPatch, options?: ApiCallOptions) => Promise<PatchMlExperimentVersionHttpResponse>;
type PatchMlExperimentVersionHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type PatchMlExperimentVersionHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Cancels jobs for an experiment version or batch prediction.
 *
 * @param corrType The type of a resource paired with a corrId
 * @param corrId The ID of a correlated resource of corrType
 * @throws CancelMlJobHttpError
 */
declare const cancelMlJob: (corrType: string, corrId: string, options?: ApiCallOptions) => Promise<CancelMlJobHttpResponse>;
type CancelMlJobHttpResponse = {
    data: void;
    headers: Headers;
    status: 204;
};
type CancelMlJobHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Starts creating profile insights for an experiment dataset.
 * This is an asynchronous operation. A `202 Accepted` response indicates
 * that the process has started successfully. Use the link in the response
 * to check the status.
 *
 * @param body an object with the body content
 * @throws CreateMlProfileInsightHttpError
 */
declare const createMlProfileInsight: (body: ProfileInsightsInput, options?: ApiCallOptions) => Promise<CreateMlProfileInsightHttpResponse>;
type CreateMlProfileInsightHttpResponse = {
    data: ProfileInsightsGetResponse;
    headers: Headers;
    status: 200 | 202;
};
type CreateMlProfileInsightHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Retrieves profile insights for the specified dataset. If you received a
 * `202 Accepted` response from `POST /ml/profile-insights`, poll this
 * endpoint until a `200 OK` response with `ready` status is returned.
 *
 * @param dataSetId The Qlik catalog dataset ID
 * @throws GetMlProfileInsightHttpError
 */
declare const getMlProfileInsight: (dataSetId: string, options?: ApiCallOptions) => Promise<GetMlProfileInsightHttpResponse>;
type GetMlProfileInsightHttpResponse = {
    data: ProfileInsightsGetResponse;
    headers: Headers;
    status: 200;
};
type GetMlProfileInsightHttpError = {
    data: Failure;
    headers: Headers;
    status: number;
};
/**
 * Clears the cache for ml api requests.
 */
declare function clearCache(): void;
interface MlAPI {
    /**
     * List deployments
     * @example
     * getMlDeployments(
     *   {
     *     filter: "`filter=spaceId eq \"UUID\" and modelState eq \"enabled\"`",
     *     limit: 10,
     *     offset: 32
     *   }
     * )
     *
     * @param query an object with query parameters
     * @throws GetMlDeploymentsHttpError
     */
    getMlDeployments: typeof getMlDeployments;
    /**
     * Create a deployment
     *
     * @param body an object with the body content
     * @throws CreateMlDeploymentHttpError
     */
    createMlDeployment: typeof createMlDeployment;
    /**
     * Delete a deployment
     *
     * @param deploymentId ID of the deployment
     * @throws DeleteMlDeploymentHttpError
     */
    deleteMlDeployment: typeof deleteMlDeployment;
    /**
     * Get a deployment
     *
     * @param deploymentId ID of the deployment
     * @throws GetMlDeploymentHttpError
     */
    getMlDeployment: typeof getMlDeployment;
    /**
     * Update a deployment
     *
     * @param deploymentId ID of the deployment
     * @param body an object with the body content
     * @throws PatchMlDeploymentHttpError
     */
    patchMlDeployment: typeof patchMlDeployment;
    /**
     * Activate the model for this deployment
     *
     * @param deploymentId ID of the deployment
     * @throws ActivateModelsMlDeploymentHttpError
     */
    activateModelsMlDeployment: typeof activateModelsMlDeployment;
    /**
     * Deactivate the model for this deployment
     *
     * @param deploymentId ID of the deployment
     * @throws DeactivateModelsMlDeploymentHttpError
     */
    deactivateModelsMlDeployment: typeof deactivateModelsMlDeployment;
    /**
     * Retrieves a list of aliases based on filter parameters for a deployment.
     *
     * @param deploymentId
     * @param query an object with query parameters
     * @throws GetMlDeploymentAliasesHttpError
     */
    getMlDeploymentAliases: typeof getMlDeploymentAliases;
    /**
     * Creates an alias for a deployment.
     *
     * @param deploymentId ID of the deployment
     * @param body an object with the body content
     * @throws CreateMlDeploymentAliaseHttpError
     */
    createMlDeploymentAliase: typeof createMlDeploymentAliase;
    /**
     * Delete an alias from a deployment.
     *
     * @param deploymentId ID of the deployment
     * @param aliasId ID of the alias
     * @throws DeleteMlDeploymentAliaseHttpError
     */
    deleteMlDeploymentAliase: typeof deleteMlDeploymentAliase;
    /**
     * Retrieves an alias that exists on the deployment.
     *
     * @param deploymentId ID of the deployment
     * @param aliasId ID of the alias
     * @throws GetMlDeploymentAliaseHttpError
     */
    getMlDeploymentAliase: typeof getMlDeploymentAliase;
    /**
     * Updates an alias for a deployment.
     *
     * @param deploymentId ID of the deployment
     * @param aliasId ID of the alias
     * @param body an object with the body content
     * @throws PatchMlDeploymentAliaseHttpError
     */
    patchMlDeploymentAliase: typeof patchMlDeploymentAliase;
    /**
     * Generate predictions in a synchronous request/response
     *
     * @param deploymentId ID of the deployment
     * @param aliasName The name of the ML Deployment Alias that will be used to determine which model should be used to produce predictions
     * @param query an object with query parameters
     * @param body an object with the body content
     * @throws RunMlDeploymentAliaseRealtimePredictionsHttpError
     */
    runMlDeploymentAliaseRealtimePredictions: typeof runMlDeploymentAliaseRealtimePredictions;
    /**
     * List batch prediction configurations
     *
     * @param deploymentId ID of the deployment
     * @param query an object with query parameters
     * @throws GetMlDeploymentBatchPredictionsHttpError
     */
    getMlDeploymentBatchPredictions: typeof getMlDeploymentBatchPredictions;
    /**
     * Create a prediction configuration
     *
     * @param deploymentId ID of the deployment
     * @param body an object with the body content
     * @throws CreateMlDeploymentBatchPredictionHttpError
     */
    createMlDeploymentBatchPrediction: typeof createMlDeploymentBatchPrediction;
    /**
     * Delete a batch prediction
     *
     * @param deploymentId ID of the deployment
     * @param batchPredictionId ID of the batch prediction
     * @throws DeleteMlDeploymentBatchPredictionHttpError
     */
    deleteMlDeploymentBatchPrediction: typeof deleteMlDeploymentBatchPrediction;
    /**
     * Retrieve a batch prediction
     *
     * @param deploymentId ID of the deployment
     * @param batchPredictionId ID of the batch prediction
     * @throws GetMlDeploymentBatchPredictionHttpError
     */
    getMlDeploymentBatchPrediction: typeof getMlDeploymentBatchPrediction;
    /**
     * Updates a batch prediction
     *
     * @param deploymentId ID of the deployment
     * @param batchPredictionId ID of the batch prediction
     * @param body an object with the body content
     * @throws PatchMlDeploymentBatchPredictionHttpError
     */
    patchMlDeploymentBatchPrediction: typeof patchMlDeploymentBatchPrediction;
    /**
     * Run a batch prediction
     *
     * @param deploymentId ID of the deployment
     * @param batchPredictionId ID of the batch prediction
     * @throws PredictMlDeploymentBatchPredictionHttpError
     */
    predictMlDeploymentBatchPrediction: typeof predictMlDeploymentBatchPrediction;
    /**
     * Deletes the schedule from a batch prediction.
     *
     * @param deploymentId ID of the deployment
     * @param batchPredictionId ID of the batch prediction
     * @throws DeleteMlDeploymentBatchPredictionScheduleHttpError
     */
    deleteMlDeploymentBatchPredictionSchedule: typeof deleteMlDeploymentBatchPredictionSchedule;
    /**
     * Retrieves the schedule for a batch prediction.
     *
     * @param deploymentId ID of the deployment
     * @param batchPredictionId ID of the batch prediction
     * @throws GetMlDeploymentBatchPredictionScheduleHttpError
     */
    getMlDeploymentBatchPredictionSchedule: typeof getMlDeploymentBatchPredictionSchedule;
    /**
     * Updates the schedule for a batch prediction.
     *
     * @param deploymentId ID of the deployment
     * @param batchPredictionId ID of the batch prediction
     * @param body an object with the body content
     * @throws UpdateMlDeploymentBatchPredictionScheduleHttpError
     */
    updateMlDeploymentBatchPredictionSchedule: typeof updateMlDeploymentBatchPredictionSchedule;
    /**
     * Adds a schedule to a batch prediction.
     *
     * @param deploymentId ID of the deployment
     * @param batchPredictionId ID of the batch prediction
     * @param body an object with the body content
     * @throws SetMlDeploymentBatchPredictionScheduleHttpError
     */
    setMlDeploymentBatchPredictionSchedule: typeof setMlDeploymentBatchPredictionSchedule;
    /**
     * Add deployed models for this deployment
     *
     * @param deploymentId ID of the deployment
     * @param body an object with the body content
     * @throws AddMlDeploymentModelsHttpError
     */
    addMlDeploymentModels: typeof addMlDeploymentModels;
    /**
     * Remove deployed models from this deployment
     *
     * @param deploymentId ID of the deployment
     * @param body an object with the body content
     * @throws RemoveMlDeploymentModelsHttpError
     */
    removeMlDeploymentModels: typeof removeMlDeploymentModels;
    /**
     * Generate predictions in a synchronous request/response
     *
     * @param deploymentId ID of the deployment
     * @param query an object with query parameters
     * @param body an object with the body content
     * @throws RunMlDeploymentRealtimePredictionsHttpError
     */
    runMlDeploymentRealtimePredictions: typeof runMlDeploymentRealtimePredictions;
    /**
     * Retrieves a list of experiments based on provided filter and sort
     * parameters.
     * @example
     * getMlExperiments(
     *   {
     *     filter: "`filter=ownerId eq UUID and experimentVersionId eq UUID`",
     *     limit: 10,
     *     offset: 32
     *   }
     * )
     *
     * @param query an object with query parameters
     * @throws GetMlExperimentsHttpError
     */
    getMlExperiments: typeof getMlExperiments;
    /**
     * Create an experiment
     *
     * @param body an object with the body content
     * @throws CreateMlExperimentHttpError
     */
    createMlExperiment: typeof createMlExperiment;
    /**
     * Delete an experiment
     *
     * @param experimentId ID of the experiment
     * @throws DeleteMlExperimentHttpError
     */
    deleteMlExperiment: typeof deleteMlExperiment;
    /**
     * Get an experiment
     *
     * @param experimentId ID of the experiment
     * @throws GetMlExperimentHttpError
     */
    getMlExperiment: typeof getMlExperiment;
    /**
     * Update an experiment
     *
     * @param experimentId ID of the experiment
     * @param body an object with the body content
     * @throws PatchMlExperimentHttpError
     */
    patchMlExperiment: typeof patchMlExperiment;
    /**
     * List models
     *
     * @param experimentId ID of the experiment
     * @param query an object with query parameters
     * @throws GetMlExperimentModelsHttpError
     */
    getMlExperimentModels: typeof getMlExperimentModels;
    /**
     * Get a model
     *
     * @param experimentId ID of the experiment
     * @param modelId ID of the model
     * @throws GetMlExperimentModelHttpError
     */
    getMlExperimentModel: typeof getMlExperimentModel;
    /**
     * List experiment versions
     *
     * @param experimentId ID of the experiment
     * @param query an object with query parameters
     * @throws GetMlExperimentVersionsHttpError
     */
    getMlExperimentVersions: typeof getMlExperimentVersions;
    /**
     * Creates an experiment version.
     * Poll this version and check its `status` field to determine when models
     * are finished training.
     *
     * @param experimentId ID of the experiment
     * @param body an object with the body content
     * @throws CreateMlExperimentVersionHttpError
     */
    createMlExperimentVersion: typeof createMlExperimentVersion;
    /**
     * Delete an experiment version
     *
     * @param experimentId ID of the experiment
     * @param experimentVersionId ID of the experiment version
     * @throws DeleteMlExperimentVersionHttpError
     */
    deleteMlExperimentVersion: typeof deleteMlExperimentVersion;
    /**
     * Get an experiment version
     *
     * @param experimentId ID of the experiment
     * @param experimentVersionId ID of the experiment version
     * @throws GetMlExperimentVersionHttpError
     */
    getMlExperimentVersion: typeof getMlExperimentVersion;
    /**
     * Update an experiment version
     *
     * @param experimentId ID of the experiment
     * @param experimentVersionId ID of the experiment version
     * @param body an object with the body content
     * @throws PatchMlExperimentVersionHttpError
     */
    patchMlExperimentVersion: typeof patchMlExperimentVersion;
    /**
     * Cancels jobs for an experiment version or batch prediction.
     *
     * @param corrType The type of a resource paired with a corrId
     * @param corrId The ID of a correlated resource of corrType
     * @throws CancelMlJobHttpError
     */
    cancelMlJob: typeof cancelMlJob;
    /**
     * Starts creating profile insights for an experiment dataset.
     * This is an asynchronous operation. A `202 Accepted` response indicates
     * that the process has started successfully. Use the link in the response
     * to check the status.
     *
     * @param body an object with the body content
     * @throws CreateMlProfileInsightHttpError
     */
    createMlProfileInsight: typeof createMlProfileInsight;
    /**
     * Retrieves profile insights for the specified dataset. If you received a
     * `202 Accepted` response from `POST /ml/profile-insights`, poll this
     * endpoint until a `200 OK` response with `ready` status is returned.
     *
     * @param dataSetId The Qlik catalog dataset ID
     * @throws GetMlProfileInsightHttpError
     */
    getMlProfileInsight: typeof getMlProfileInsight;
    /**
     * Clears the cache for ml api requests.
     */
    clearCache: typeof clearCache;
}
/**
 * Functions for the ml api
 */
declare const mlExport: MlAPI;

export { type APIError, type ActivateModelsMlDeploymentHttpError, type ActivateModelsMlDeploymentHttpResponse, type AddMlDeploymentModelsHttpError, type AddMlDeploymentModelsHttpResponse, type Alias, type AliasFindResponse, type AliasGetResponse, type AliasId, type AliasInput, type AliasMode, type AliasPatch, type AliasPatchItem, type AliasPostResponse, type AnyType, type BatchPrediction, type BatchPredictionActionResponse, type BatchPredictionFindResponse, type BatchPredictionGetResponse, type BatchPredictionInput, type BatchPredictionPatch, type BatchPredictionPostResponse, type BatchPredictionSchedule, type BatchPredictionScheduleGetResponse, type BatchPredictionScheduleInput, type BatchPredictionScheduleInputAttributes, type BatchPredictionSchedulePatch, type BatchPredictionSchedulePutResponse, type BatchPredictionStatus, type BatchPredictionWriteback, type BinaryImbalanceSampling, type CancelMlJobHttpError, type CancelMlJobHttpResponse, type ChangeType, type ColumnTransform, type ConfigurationKey, type CorrId, type CorrType, type CreateMlDeploymentAliaseHttpError, type CreateMlDeploymentAliaseHttpResponse, type CreateMlDeploymentBatchPredictionHttpError, type CreateMlDeploymentBatchPredictionHttpResponse, type CreateMlDeploymentHttpError, type CreateMlDeploymentHttpResponse, type CreateMlExperimentHttpError, type CreateMlExperimentHttpResponse, type CreateMlExperimentVersionHttpError, type CreateMlExperimentVersionHttpResponse, type CreateMlProfileInsightHttpError, type CreateMlProfileInsightHttpResponse, type CreatedAt, type CreatedBy, type DataSchemaConfiguration, type DataSetId, type DataType, type DatasetOrigin, type DateIndexes, type DeactivateModelsMlDeploymentHttpError, type DeactivateModelsMlDeploymentHttpResponse, type DeleteMlDeploymentAliaseHttpError, type DeleteMlDeploymentAliaseHttpResponse, type DeleteMlDeploymentBatchPredictionHttpError, type DeleteMlDeploymentBatchPredictionHttpResponse, type DeleteMlDeploymentBatchPredictionScheduleHttpError, type DeleteMlDeploymentBatchPredictionScheduleHttpResponse, type DeleteMlDeploymentHttpError, type DeleteMlDeploymentHttpResponse, type DeleteMlExperimentHttpError, type DeleteMlExperimentHttpResponse, type DeleteMlExperimentVersionHttpError, type DeleteMlExperimentVersionHttpResponse, type DeletedAt, type DeployedModelIds, type DeployedModelsInput, type Deployment, type DeploymentFindResponse, type DeploymentGetResponse, type DeploymentId, type DeploymentInput, type DeploymentPatch, type DeploymentPostResponse, type DroppedFeature, type EntityDescription, type EntityId, type EntityName, type EnumSortAliases, type EnumSortBatchPredictions, type EnumSortDeployments, type EnumSortExperimentVersions, type EnumSortExperiments, type EnumSortModels, type ErrorMessage, type Errors, type Experiment, type ExperimentFindResponse, type ExperimentGetResponse, type ExperimentId, type ExperimentInput, type ExperimentMode, type ExperimentPatch, type ExperimentPatchItem, type ExperimentPostResponse, type ExperimentType, type ExperimentVersion, type ExperimentVersionFindResponse, type ExperimentVersionGetResponse, type ExperimentVersionId, type ExperimentVersionInput, type ExperimentVersionPatch, type ExperimentVersionPostResponse, type Failure, type Feature, type FeatureInsights, type FeatureType, type FeaturesList, type FileType, type FindResponseMeta, type GetMlDeploymentAliaseHttpError, type GetMlDeploymentAliaseHttpResponse, type GetMlDeploymentAliasesHttpError, type GetMlDeploymentAliasesHttpResponse, type GetMlDeploymentBatchPredictionHttpError, type GetMlDeploymentBatchPredictionHttpResponse, type GetMlDeploymentBatchPredictionScheduleHttpError, type GetMlDeploymentBatchPredictionScheduleHttpResponse, type GetMlDeploymentBatchPredictionsHttpError, type GetMlDeploymentBatchPredictionsHttpResponse, type GetMlDeploymentHttpError, type GetMlDeploymentHttpResponse, type GetMlDeploymentsHttpError, type GetMlDeploymentsHttpResponse, type GetMlExperimentHttpError, type GetMlExperimentHttpResponse, type GetMlExperimentModelHttpError, type GetMlExperimentModelHttpResponse, type GetMlExperimentModelsHttpError, type GetMlExperimentModelsHttpResponse, type GetMlExperimentVersionHttpError, type GetMlExperimentVersionHttpResponse, type GetMlExperimentVersionsHttpError, type GetMlExperimentVersionsHttpResponse, type GetMlExperimentsHttpError, type GetMlExperimentsHttpResponse, type GetMlProfileInsightHttpError, type GetMlProfileInsightHttpResponse, type IndexColumn, type Insights, type JobType, type MlAPI, type Model, type ModelAlgorithm, type ModelAlgorithmAbbreviation, type ModelFindResponse, type ModelGetResponse, type ModelId, type ModelInfo, type ModelMetrics, type ModelMetricsBinary, type ModelMetricsMulticlass, type ModelMetricsRegression, type ModelState, type ModelStatus, type ModelsInfo, type OutputFile, type OwnerId, type ParentJobId, type PatchMlDeploymentAliaseHttpError, type PatchMlDeploymentAliaseHttpResponse, type PatchMlDeploymentBatchPredictionHttpError, type PatchMlDeploymentBatchPredictionHttpResponse, type PatchMlDeploymentHttpError, type PatchMlDeploymentHttpResponse, type PatchMlExperimentHttpError, type PatchMlExperimentHttpResponse, type PatchMlExperimentVersionHttpError, type PatchMlExperimentVersionHttpResponse, type Pipeline, type PredictMlDeploymentBatchPredictionHttpError, type PredictMlDeploymentBatchPredictionHttpResponse, type PredictionJobResponse, type PreprocessedInsightColumn, type ProfileInsights, type ProfileInsightsGetResponse, type ProfileInsightsInput, type RealTimePredictionInputSchema, type RealTimePredictionSchema, type RealtimePrediction, type RealtimePredictionInput, type RemoveMlDeploymentModelsHttpError, type RemoveMlDeploymentModelsHttpResponse, type ResponseLinks, type RunMlDeploymentAliaseRealtimePredictionsHttpError, type RunMlDeploymentAliaseRealtimePredictionsHttpResponse, type RunMlDeploymentRealtimePredictionsHttpError, type RunMlDeploymentRealtimePredictionsHttpResponse, type SetMlDeploymentBatchPredictionScheduleHttpError, type SetMlDeploymentBatchPredictionScheduleHttpResponse, type SpaceId, type TenantId, type TrainingDuration, type Transform, type UpdateMlDeploymentBatchPredictionScheduleHttpError, type UpdateMlDeploymentBatchPredictionScheduleHttpResponse, type UpdatedAt, activateModelsMlDeployment, addMlDeploymentModels, cancelMlJob, clearCache, createMlDeployment, createMlDeploymentAliase, createMlDeploymentBatchPrediction, createMlExperiment, createMlExperimentVersion, createMlProfileInsight, deactivateModelsMlDeployment, mlExport as default, deleteMlDeployment, deleteMlDeploymentAliase, deleteMlDeploymentBatchPrediction, deleteMlDeploymentBatchPredictionSchedule, deleteMlExperiment, deleteMlExperimentVersion, getMlDeployment, getMlDeploymentAliase, getMlDeploymentAliases, getMlDeploymentBatchPrediction, getMlDeploymentBatchPredictionSchedule, getMlDeploymentBatchPredictions, getMlDeployments, getMlExperiment, getMlExperimentModel, getMlExperimentModels, getMlExperimentVersion, getMlExperimentVersions, getMlExperiments, getMlProfileInsight, patchMlDeployment, patchMlDeploymentAliase, patchMlDeploymentBatchPrediction, patchMlExperiment, patchMlExperimentVersion, predictMlDeploymentBatchPrediction, removeMlDeploymentModels, runMlDeploymentAliaseRealtimePredictions, runMlDeploymentRealtimePredictions, setMlDeploymentBatchPredictionSchedule, updateMlDeploymentBatchPredictionSchedule };
